@@ -7,7 +7,7 @@ use CPAN::Changes;
 use Test::Builder;
 use version ();
 
-our $VERSION = '0.19';
+our $VERSION = '0.27';
 
 my $Test     = Test::Builder->new;
 
@@ -53,12 +53,18 @@ sub changes_file_ok {
     $Test->ok( 1, "$file contains at least one release" );
 
     for ( @releases ) {
-        if ( $_->date !~ m[^${CPAN::Changes::W3CDTF_REGEX}\s*$] ) {
+        if ( !defined $_->date || $_->date eq ''  ) {
             $Test->ok( 0, "$file contains an invalid release date" );
-            $Test->diag( '  ERR: ' . $_->date );
+            $Test->diag( '  ERR: No date at version ' . $_->version );
             return;
         }
 
+        my $d = $_->{ _parsed_date };
+        if ( $d !~ m[^${CPAN::Changes::W3CDTF_REGEX}$]
+                && $d !~ m[^(${CPAN::Changes::UNKNOWN_VALS})$] ) {
+            $Test->carp( 'Date "' . $d . '" is not in the recommended format' );
+        }
+
         # strip off -TRIAL before testing
         (my $version = $_->version) =~ s/-TRIAL$//;
         if ( not version::is_lax($version) ) {
@@ -146,7 +152,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2011 by Brian Cassidy
+Copyright 2011-2013 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
